@@ -129,7 +129,7 @@ class ExbetAPI:
             time.sleep(self._SLEEPTIME)
             cnt += 1
             if cnt > 3 * self._BLOCKTIME / self._SLEEPTIME:
-                raise ExecutionError("Inform admins")
+                raise ExecutionError(f"Inform admins {task_id}: {str(task)}")
 
     @staticmethod
     def _obtain_task_results(task):  # pragma: no cover
